==> viking-1.6.2.tar.bz2: viking-1.6.2/src/icons/icons.c <==
/* Generated file */
#include <gdk-pixbuf/gdk-pixdata.h>
#include "addtr_18_pixmap.h"
#include "addwp_18_pixmap.h"
#include "begintr_18_pixmap.h"
#include "bing_maps_pixmap.h"
#include "cursor_addtr_pixmap.h"
#include "cursor_addwp_pixmap.h"
#include "cursor_begintr_pixmap.h"
#include "cursor_demdl_pixmap.h"
#include "cursor_edtr_pixmap.h"
#include "cursor_edwp_pixmap.h"
#include "cursor_geomove_pixmap.h"
#include "cursor_geozoom_pixmap.h"
#include "cursor_mapdl_pixmap.h"
#include "cursor_new_route_pixmap.h"
#include "cursor_route_finder_pixmap.h"
#include "cursor_ruler_pixmap.h"
#include "cursor_showpic_pixmap.h"
#include "cursor_zoom_pixmap.h"
#include "demdl_18_pixmap.h"
#include "edtr_18_pixmap.h"
#include "edwp_18_pixmap.h"
#include "geomove_18_pixmap.h"
#include "geozoom_18_pixmap.h"
#include "mapdl_18_pixmap.h"
#include "mover_22_pixmap.h"
#include "route_finder_18_pixmap.h"
#include "ruler_18_pixmap.h"
#include "select_18_pixmap.h"
#include "showpic_18_pixmap.h"
#include "thumbnails_pixmap.h"
#include "vikaggregatelayer_pixmap.h"
#include "vikcoordlayer_pixmap.h"
#include "vikdemlayer_pixmap.h"
#include "vikgeoreflayer_pixmap.h"
#include "vikgpslayer_pixmap.h"
#include "viking_pixmap.h"
#include "vikmapniklayer_pixmap.h"
#include "vikmapslayer_pixmap.h"
#include "vik_new_route_18_pixmap.h"
#include "viktrwlayer_pixmap.h"
#include "wp_1st_aid_large_pixmap.h"
#include "wp_1st_aid_pixmap.h"
#include "wp_airplane_large_pixmap.h"
#include "wp_airplane_pixmap.h"
#include "wp_amuse_pk_large_pixmap.h"
#include "wp_anchor_large_pixmap.h"
#include "wp_anchor_pixmap.h"
#include "wp_ball_large_pixmap.h"
#include "wp_ball_pixmap.h"
#include "wp_beach_large_pixmap.h"
#include "wp_beach_pixmap.h"
#include "wp_bell_large_pixmap.h"
#include "wp_bell_pixmap.h"
#include "wp_bike_trail_large_pixmap.h"
#include "wp_block_blue_large_pixmap.h"
#include "wp_block_green_large_pixmap.h"
#include "wp_block_red_large_pixmap.h"
#include "wp_boat_ramp_large_pixmap.h"
#include "wp_boat_ramp_pixmap.h"
#include "wp_bowling_large_pixmap.h"
#include "wp_bridge_large_pixmap.h"
#include "wp_bridge_pixmap.h"
#include "wp_building_large_pixmap.h"
#include "wp_building_pixmap.h"
#include "wp_buoy_ambr_large_pixmap.h"
#include "wp_buoy_ambr_pixmap.h"
#include "wp_buoy_blck_large_pixmap.h"
#include "wp_buoy_blck_pixmap.h"
#include "wp_buoy_blue_large_pixmap.h"
#include "wp_buoy_blue_pixmap.h"
#include "wp_buoy_grn_large_pixmap.h"
#include "wp_buoy_grn_pixmap.h"
#include "wp_buoy_grn_red_large_pixmap.h"
#include "wp_buoy_grn_red_pixmap.h"
#include "wp_buoy_grn_wht_large_pixmap.h"
#include "wp_buoy_grn_wht_pixmap.h"
#include "wp_buoy_orng_large_pixmap.h"
#include "wp_buoy_orng_pixmap.h"
#include "wp_buoy_red_grn_large_pixmap.h"
#include "wp_buoy_red_grn_pixmap.h"
#include "wp_buoy_red_large_pixmap.h"
#include "wp_buoy_red_pixmap.h"
#include "wp_buoy_red_wht_large_pixmap.h"
#include "wp_buoy_red_wht_pixmap.h"
#include "wp_buoy_violet_large_pixmap.h"
#include "wp_buoy_violet_pixmap.h"
#include "wp_buoy_wht_grn_large_pixmap.h"
#include "wp_buoy_wht_grn_pixmap.h"
#include "wp_buoy_wht_large_pixmap.h"
#include "wp_buoy_wht_pixmap.h"
#include "wp_buoy_wht_red_large_pixmap.h"
#include "wp_buoy_wht_red_pixmap.h"
#include "wp_camp_large_pixmap.h"
#include "wp_camp_pixmap.h"
#include "wp_cap_cty_pixmap.h"
#include "wp_car_large_pixmap.h"
#include "wp_car_pixmap.h"
#include "wp_car_rental_large_pixmap.h"
#include "wp_car_repair_large_pixmap.h"
#include "wp_cemetery_large_pixmap.h"
#include "wp_cemetery_pixmap.h"
#include "wp_church_large_pixmap.h"
#include "wp_church_pixmap.h"
#include "wp_civil_large_pixmap.h"
#include "wp_controlled_large_pixmap.h"
#include "wp_controlled_pixmap.h"
#include "wp_conv_store_large_pixmap.h"
#include "wp_crossing_large_pixmap.h"
#include "wp_dam_large_pixmap.h"
#include "wp_dam_pixmap.h"
#include "wp_danger_large_pixmap.h"
#include "wp_danger_pixmap.h"
#include "wp_deer_large_pixmap.h"
#include "wp_deer_pixmap.h"
#include "wp_diamond_grn_pixmap.h"
#include "wp_diamond_red_pixmap.h"
#include "wp_dive1_large_pixmap.h"
#include "wp_dive1_pixmap.h"
#include "wp_dive2_large_pixmap.h"
#include "wp_dive2_pixmap.h"
#include "wp_dollar_large_pixmap.h"
#include "wp_dollar_pixmap.h"
#include "wp_dot_pixmap.h"
#include "wp_drinking_wtr_large_pixmap.h"
#include "wp_drinking_wtr_pixmap.h"
#include "wp_exit_large_pixmap.h"
#include "wp_fastfood_large_pixmap.h"
#include "wp_fhs_facility_large_pixmap.h"
#include "wp_fish_large_pixmap.h"
#include "wp_fish_pixmap.h"
#include "wp_fitness_large_pixmap.h"
#include "wp_flag_blue_large_pixmap.h"
#include "wp_flag_green_large_pixmap.h"
#include "wp_flag_pixmap.h"
#include "wp_flag_red_large_pixmap.h"
#include "wp_forest_large_pixmap.h"
#include "wp_forest_pixmap.h"
#include "wp_fuel_large_pixmap.h"
#include "wp_fuel_pixmap.h"
#include "wp_geocache_fnd_large_pixmap.h"
#include "wp_geocache_fnd_pixmap.h"
#include "wp_geocache_large_pixmap.h"
#include "wp_geocache_pixmap.h"
#include "wp_glider_large_pixmap.h"
#include "wp_golf_large_pixmap.h"
#include "wp_golf_pixmap.h"
#include "wp_grnd_trans_large_pixmap.h"
#include "wp_helipad_large_pixmap.h"
#include "wp_horn_large_pixmap.h"
#include "wp_horn_pixmap.h"
#include "wp_house_large_pixmap.h"
#include "wp_house_pixmap.h"
#include "wp_ice_skating_large_pixmap.h"
#include "wp_ice_skating_pixmap.h"
#include "wp_info_large_pixmap.h"
#include "wp_info_pixmap.h"
#include "wp_knife_large_pixmap.h"
#include "wp_knife_pixmap.h"
#include "wp_light_large_pixmap.h"
#include "wp_light_pixmap.h"
#include "wp_lodging_large_pixmap.h"
#include "wp_lrg_cty_large_pixmap.h"
#include "wp_lrg_cty_pixmap.h"
#include "wp_med_cty_large_pixmap.h"
#include "wp_med_cty_pixmap.h"
#include "wp_military_pixmap.h"
#include "wp_mine_large_pixmap.h"
#include "wp_mine_pixmap.h"
#include "wp_mob_large_pixmap.h"
#include "wp_mob_pixmap.h"
#include "wp_movie_large_pixmap.h"
#include "wp_mug_large_pixmap.h"
#include "wp_mug_pixmap.h"
#include "wp_museum_large_pixmap.h"
#include "wp_null_pixmap.h"
#include "wp_oil_field_large_pixmap.h"
#include "wp_parachute_large_pixmap.h"
#include "wp_parking_large_pixmap.h"
#include "wp_parking_pixmap.h"
#include "wp_park_large_pixmap.h"
#include "wp_park_pixmap.h"
#include "wp_pharmacy_large_pixmap.h"
#include "wp_phone_large_pixmap.h"
#include "wp_phone_pixmap.h"
#include "wp_picnic_large_pixmap.h"
#include "wp_picnic_pixmap.h"
#include "wp_pin_blue_large_pixmap.h"
#include "wp_pin_green_large_pixmap.h"
#include "wp_pin_red_large_pixmap.h"
#include "wp_pizza_large_pixmap.h"
#include "wp_police_large_pixmap.h"
#include "wp_post_ofc_large_pixmap.h"
#include "wp_rbcn_large_pixmap.h"
#include "wp_rbcn_pixmap.h"
#include "wp_restricted_large_pixmap.h"
#include "wp_restricted_pixmap.h"
#include "wp_restroom_large_pixmap.h"
#include "wp_restroom_pixmap.h"
#include "wp_rv_park_large_pixmap.h"
#include "wp_rv_park_pixmap.h"
#include "wp_scenic_large_pixmap.h"
#include "wp_scenic_pixmap.h"
#include "wp_school_large_pixmap.h"
#include "wp_school_pixmap.h"
#include "wp_shopping_large_pixmap.h"
#include "wp_short_tower_large_pixmap.h"
#include "wp_shower_large_pixmap.h"
#include "wp_shower_pixmap.h"
#include "wp_skiing_large_pixmap.h"
#include "wp_skiing_pixmap.h"
#include "wp_ski_resort_large_pixmap.h"
#include "wp_skull_large_pixmap.h"
#include "wp_skull_pixmap.h"
#include "wp_sml_cty_large_pixmap.h"
#include "wp_sml_cty_pixmap.h"
#include "wp_square_grn_pixmap.h"
#include "wp_square_red_pixmap.h"
#include "wp_stadium_large_pixmap.h"
#include "wp_store_large_pixmap.h"
#include "wp_summit_large_pixmap.h"
#include "wp_summit_pixmap.h"
#include "wp_swimming_large_pixmap.h"
#include "wp_swimming_pixmap.h"
#include "wp_tall_tower_large_pixmap.h"
#include "wp_theater_large_pixmap.h"
#include "wp_toll_booth_large_pixmap.h"
#include "wp_trail_head_large_pixmap.h"
#include "wp_truck_stop_large_pixmap.h"
#include "wp_tunnel_large_pixmap.h"
#include "wp_tunnel_pixmap.h"
#include "wp_ultralight_large_pixmap.h"
#include "wp_wbuoy_large_pixmap.h"
#include "wp_wbuoy_pixmap.h"
#include "wp_weigh_station_large_pixmap.h"
#include "wp_wpt_dot_pixmap.h"
#include "wp_wrecker_large_pixmap.h"
#include "wp_wreck_large_pixmap.h"
#include "wp_wreck_pixmap.h"
#include "wp_zoo_large_pixmap.h"
#include "zoom_18_pixmap.h"

==> viking-1.7.tar.bz2: viking-1.7/src/icons/icons.c <==
/* Generated file */
#include <gdk-pixbuf/gdk-pixdata.h>
#include "viking_pixmap.h"
#include "bing_maps_pixmap.h"
#include "addtr_18_pixmap.h"
#include "vik_new_route_18_pixmap.h"
#include "addwp_18_pixmap.h"
#include "edtr_18_pixmap.h"
#include "edwp_18_pixmap.h"
#include "geomove_18_pixmap.h"
#include "geozoom_18_pixmap.h"
#include "mapdl_18_pixmap.h"
#include "demdl_18_pixmap.h"
#include "mover_22_pixmap.h"
#include "ruler_18_pixmap.h"
#include "showpic_18_pixmap.h"
#include "zoom_18_pixmap.h"
#include "route_finder_18_pixmap.h"
#include "splitter_18_pixmap.h"
#include "select_18_pixmap.h"
#include "thumbnails_pixmap.h"
#include "vikaggregatelayer_pixmap.h"
#include "vikcoordlayer_pixmap.h"
#include "vikdemlayer_pixmap.h"
#include "vikgeoreflayer_pixmap.h"
#include "vikgpslayer_pixmap.h"
#include "vikmapslayer_pixmap.h"
#include "vikmapniklayer_pixmap.h"
#include "viktrwlayer_pixmap.h"
#include "viktrwlayer_external_pixmap.h"
#include "viktrwlayer_external_nowrite_pixmap.h"
#include "wp_camp_pixmap.h"
#include "wp_car_pixmap.h"
#include "wp_deer_pixmap.h"
#include "wp_flag_pixmap.h"
#include "wp_geocache_pixmap.h"
#include "wp_geocache_fnd_pixmap.h"
#include "wp_house_pixmap.h"
#include "wp_wpt_dot_pixmap.h"
#include "wp_dollar_pixmap.h"
#include "wp_golf_pixmap.h"
#include "wp_summit_pixmap.h"
#include "wp_anchor_pixmap.h"
#include "wp_forest_pixmap.h"
#include "wp_parking_pixmap.h"
#include "wp_sml_cty_pixmap.h"
#include "wp_med_cty_pixmap.h"
#include "wp_lrg_cty_pixmap.h"
#include "wp_cap_cty_pixmap.h"
#include "wp_bell_pixmap.h"
#include "wp_diamond_grn_pixmap.h"
#include "wp_diamond_red_pixmap.h"
#include "wp_dive1_pixmap.h"
#include "wp_dive2_pixmap.h"
#include "wp_fish_pixmap.h"
#include "wp_fuel_pixmap.h"
#include "wp_horn_pixmap.h"
#include "wp_knife_pixmap.h"
#include "wp_light_pixmap.h"
#include "wp_mug_pixmap.h"
#include "wp_skull_pixmap.h"
#include "wp_square_grn_pixmap.h"
#include "wp_square_red_pixmap.h"
#include "wp_wbuoy_pixmap.h"
#include "wp_wreck_pixmap.h"
#include "wp_null_pixmap.h"
#include "wp_mine_pixmap.h"
#include "wp_school_pixmap.h"
#include "wp_cemetery_pixmap.h"
#include "wp_church_pixmap.h"
#include "wp_military_pixmap.h"
#include "wp_mob_pixmap.h"
#include "wp_buoy_ambr_pixmap.h"
#include "wp_buoy_blck_pixmap.h"
#include "wp_buoy_blue_pixmap.h"
#include "wp_buoy_grn_pixmap.h"
#include "wp_buoy_grn_red_pixmap.h"
#include "wp_buoy_grn_wht_pixmap.h"
#include "wp_buoy_orng_pixmap.h"
#include "wp_buoy_red_pixmap.h"
#include "wp_buoy_red_grn_pixmap.h"
#include "wp_buoy_red_wht_pixmap.h"
#include "wp_buoy_violet_pixmap.h"
#include "wp_buoy_wht_pixmap.h"
#include "wp_buoy_wht_grn_pixmap.h"
#include "wp_buoy_wht_red_pixmap.h"
#include "wp_dot_pixmap.h"
#include "wp_rbcn_pixmap.h"
#include "wp_boat_ramp_pixmap.h"
#include "wp_restroom_pixmap.h"
#include "wp_shower_pixmap.h"
#include "wp_drinking_wtr_pixmap.h"
#include "wp_phone_pixmap.h"
#include "wp_1st_aid_pixmap.h"
#include "wp_info_pixmap.h"
#include "wp_park_pixmap.h"
#include "wp_picnic_pixmap.h"
#include "wp_scenic_pixmap.h"
#include "wp_skiing_pixmap.h"
#include "wp_swimming_pixmap.h"
#include "wp_dam_pixmap.h"
#include "wp_controlled_pixmap.h"
#include "wp_danger_pixmap.h"
#include "wp_restricted_pixmap.h"
#include "wp_ball_pixmap.h"
#include "wp_rv_park_pixmap.h"
#include "wp_bridge_pixmap.h"
#include "wp_building_pixmap.h"
#include "wp_tunnel_pixmap.h"
#include "wp_beach_pixmap.h"
#include "wp_airplane_pixmap.h"
#include "wp_ice_skating_pixmap.h"
#include "wp_1st_aid_large_pixmap.h"
#include "wp_airplane_large_pixmap.h"
#include "wp_amuse_pk_large_pixmap.h"
#include "wp_anchor_large_pixmap.h"
#include "wp_animal_tracks_large_pixmap.h"
#include "wp_atv_large_pixmap.h"
#include "wp_ball_large_pixmap.h"
#include "wp_beach_large_pixmap.h"
#include "wp_bell_large_pixmap.h"
#include "wp_big_game_large_pixmap.h"
#include "wp_bike_trail_large_pixmap.h"
#include "wp_blind_large_pixmap.h"
#include "wp_blood_trail_large_pixmap.h"
#include "wp_block_blue_large_pixmap.h"
#include "wp_block_green_large_pixmap.h"
#include "wp_block_red_large_pixmap.h"
#include "wp_boat_ramp_large_pixmap.h"
#include "wp_bowling_large_pixmap.h"
#include "wp_bridge_large_pixmap.h"
#include "wp_building_large_pixmap.h"
#include "wp_buoy_ambr_large_pixmap.h"
#include "wp_buoy_blck_large_pixmap.h"
#include "wp_buoy_blue_large_pixmap.h"
#include "wp_buoy_grn_large_pixmap.h"
#include "wp_buoy_grn_red_large_pixmap.h"
#include "wp_buoy_grn_wht_large_pixmap.h"
#include "wp_buoy_orng_large_pixmap.h"
#include "wp_buoy_red_grn_large_pixmap.h"
#include "wp_buoy_red_large_pixmap.h"
#include "wp_buoy_red_wht_large_pixmap.h"
#include "wp_buoy_violet_large_pixmap.h"
#include "wp_buoy_wht_grn_large_pixmap.h"
#include "wp_buoy_wht_large_pixmap.h"
#include "wp_buoy_wht_red_large_pixmap.h"
#include "wp_camp_large_pixmap.h"
#include "wp_car_large_pixmap.h"
#include "wp_car_rental_large_pixmap.h"
#include "wp_car_repair_large_pixmap.h"
#include "wp_cemetery_large_pixmap.h"
#include "wp_church_large_pixmap.h"
#include "wp_civil_large_pixmap.h"
#include "wp_controlled_large_pixmap.h"
#include "wp_conv_store_large_pixmap.h"
#include "wp_cover_large_pixmap.h"
#include "wp_covey_large_pixmap.h"
#include "wp_crossing_large_pixmap.h"
#include "wp_dam_large_pixmap.h"
#include "wp_danger_large_pixmap.h"
#include "wp_deer_large_pixmap.h"
#include "wp_dive1_large_pixmap.h"
#include "wp_dive2_large_pixmap.h"
#include "wp_dollar_large_pixmap.h"
#include "wp_drinking_wtr_large_pixmap.h"
#include "wp_exit_large_pixmap.h"
#include "wp_fastfood_large_pixmap.h"
#include "wp_fhs_facility_large_pixmap.h"
#include "wp_fish_large_pixmap.h"
#include "wp_fitness_large_pixmap.h"
#include "wp_flag_blue_large_pixmap.h"
#include "wp_flag_green_large_pixmap.h"
#include "wp_flag_red_large_pixmap.h"
#include "wp_food_source_large_pixmap.h"
#include "wp_forest_large_pixmap.h"
#include "wp_fuel_large_pixmap.h"
#include "wp_furbearer_large_pixmap.h"
#include "wp_geocache_fnd_large_pixmap.h"
#include "wp_geocache_large_pixmap.h"
#include "wp_glider_large_pixmap.h"
#include "wp_golf_large_pixmap.h"
#include "wp_grnd_trans_large_pixmap.h"
#include "wp_helipad_large_pixmap.h"
#include "wp_horn_large_pixmap.h"
#include "wp_house_large_pixmap.h"
#include "wp_ice_skating_large_pixmap.h"
#include "wp_info_large_pixmap.h"
#include "wp_knife_large_pixmap.h"
#include "wp_light_large_pixmap.h"
#include "wp_lodging_large_pixmap.h"
#include "wp_lodge_large_pixmap.h"
#include "wp_lrg_cty_large_pixmap.h"
#include "wp_med_cty_large_pixmap.h"
#include "wp_mine_large_pixmap.h"
#include "wp_mob_large_pixmap.h"
#include "wp_movie_large_pixmap.h"
#include "wp_mug_large_pixmap.h"
#include "wp_museum_large_pixmap.h"
#include "wp_oil_field_large_pixmap.h"
#include "wp_parachute_large_pixmap.h"
#include "wp_parking_large_pixmap.h"
#include "wp_park_large_pixmap.h"
#include "wp_pharmacy_large_pixmap.h"
#include "wp_phone_large_pixmap.h"
#include "wp_picnic_large_pixmap.h"
#include "wp_pin_blue_large_pixmap.h"
#include "wp_pin_green_large_pixmap.h"
#include "wp_pin_red_large_pixmap.h"
#include "wp_pizza_large_pixmap.h"
#include "wp_police_large_pixmap.h"
#include "wp_post_ofc_large_pixmap.h"
#include "wp_rbcn_large_pixmap.h"
#include "wp_restricted_large_pixmap.h"
#include "wp_restroom_large_pixmap.h"
#include "wp_rv_park_large_pixmap.h"
#include "wp_scenic_large_pixmap.h"
#include "wp_school_large_pixmap.h"
#include "wp_shopping_large_pixmap.h"
#include "wp_short_tower_large_pixmap.h"
#include "wp_shower_large_pixmap.h"
#include "wp_skiing_large_pixmap.h"
#include "wp_ski_resort_large_pixmap.h"
#include "wp_skull_large_pixmap.h"
#include "wp_small_game_large_pixmap.h"
#include "wp_sml_cty_large_pixmap.h"
#include "wp_stadium_large_pixmap.h"
#include "wp_store_large_pixmap.h"
#include "wp_summit_large_pixmap.h"
#include "wp_swimming_large_pixmap.h"
#include "wp_tall_tower_large_pixmap.h"
#include "wp_theater_large_pixmap.h"
#include "wp_toll_booth_large_pixmap.h"
#include "wp_trail_head_large_pixmap.h"
#include "wp_tree_stand_large_pixmap.h"
#include "wp_treed_quarry_large_pixmap.h"
#include "wp_truck_large_pixmap.h"
#include "wp_truck_stop_large_pixmap.h"
#include "wp_tunnel_large_pixmap.h"
#include "wp_upland_game_large_pixmap.h"
#include "wp_ultralight_large_pixmap.h"
#include "wp_water_source_large_pixmap.h"
#include "wp_waterfowl_large_pixmap.h"
#include "wp_wbuoy_large_pixmap.h"
#include "wp_weigh_station_large_pixmap.h"
#include "wp_wrecker_large_pixmap.h"
#include "wp_wreck_large_pixmap.h"
#include "wp_zoo_large_pixmap.h"
#include "cursor_addtr_pixmap.h"
#include "cursor_new_route_pixmap.h"
#include "cursor_edtr_pixmap.h"
#include "cursor_geozoom_pixmap.h"
#include "cursor_ruler_pixmap.h"
#include "cursor_addwp_pixmap.h"
#include "cursor_edwp_pixmap.h"
#include "cursor_route_finder_pixmap.h"
#include "cursor_splitter_pixmap.h"
#include "cursor_showpic_pixmap.h"
#include "cursor_demdl_pixmap.h"
#include "cursor_geomove_pixmap.h"
#include "cursor_mapdl_pixmap.h"
#include "cursor_zoom_pixmap.h"
